
rm(list=ls())

library(grDevices)
library(ggplot2)
library(gridExtra)
library(jpeg)
library(grid)
library(raster)
library(graphics)
library(magick)
library(patchwork)
library(here)

finmarchicus<-readJPEG("finmarchicus.jpg", TRUE)
glacialis<-readJPEG("glacialis.jpg", TRUE)
metridia<-readJPEG("metridia.jpg", TRUE)


glacialis<-rasterGrob(glacialis, interpolate=TRUE)
finmarchicus <- rasterGrob(finmarchicus, interpolate=TRUE)
metridia <- rasterGrob(metridia, interpolate=TRUE)

# mag 0.6: 12 mm is 895.09 px
# mag 1: 9mm is 938.03 px
# mag 1.6: 5mm is 826.02 px

mag_1.6<-data.frame(y1=0,x1=0,x2=2*(826.02/5),y2=0)

# *.2 is to standardize after scale_y_continuous

x1=0; x2=2*(826.02/5)

2*(826.02/5) # 2 mm is 330.408 px

(x1+647*0.1) - (x2+647*0.1)

finmarchicus_photo<-ggplot() +
  annotation_custom(finmarchicus, xmin=0, xmax=647, ymin=0, ymax=486) +
  scale_y_continuous(limits=c(0,486), expand=c(0,0))+
  scale_x_continuous(limits=c(0,647), expand=c(0,0), breaks = c(0,64.7,330.408+64.7)) +
  labs(title = expression(italic("C. finmarchicus")))+
  geom_segment(aes(y=y1+486*.2, x=x1-50+647*0.1, yend=y2+486*.2, xend=x2-50+647*0.1), size=1.5, data = mag_1.6)+
  annotate("text", x = 2*(826.02/5) + 647*0.1 + 100, y = 486*.2, label = "2 mm",parse=F,size=3,colour="black")+
  theme(axis.text.y = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.ticks.y =element_blank(),
        plot.title = element_text(size = 8, vjust = -13.5), #vjust-2 size 10
        panel.background = element_rect(fill = "white", colour = "white"),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        plot.margin = margin(-5, 1, -5, 1))

str(glacialis)

(x1+904*0.1) - (x2+904*0.1)

904/647 # pixel relationship between panels of M. longa, C. finmarchicus vs. C. glacialis, thats why geom segment has + 50 vs. + 70, and annotate has + 100 vs + 140

glacialis_photo<-ggplot() +
  annotation_custom(glacialis, xmin=0,xmax=904, ymin=0, ymax=678) +
  scale_y_continuous(limits=c(0,678), expand=c(0,0))+
  scale_x_continuous(limits=c(0,904), expand=c(0,0), breaks = c(0,90.4,330.408+90.4)) +
  labs(title = expression(italic("C. glacialis")))+
  geom_segment(aes(y=y1+678*0.2, x=x1-70+904*0.1, yend=y2+678*0.2, xend=x2-70+904*0.1),size=1.5,data = mag_1.6)+
  annotate("text", x = 2*(826.02/5) + 904*0.1 + 140, y = 678*0.2, label = "2 mm",parse=F,size=3,colour="black")+
  theme(axis.text.y = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.ticks.y =element_blank(),
        plot.title = element_text(size = 8, vjust = -13.5),
        panel.background = element_rect(fill = "white", colour = "white"),
        axis.title.x = element_blank(),
        plot.margin = margin(-5, 1, -5, 1),
        axis.title.y = element_blank())

str(metridia)

metridia_photo<-ggplot() +
  annotation_custom(metridia, xmin=0,xmax=646, ymin=0, ymax=487) +
  scale_y_continuous(limits=c(0,486), expand=c(0,0))+
  scale_x_continuous(limits=c(0,647), expand=c(0,0), breaks = c(0,64.7,330.408+64.7)) +
  labs(title = expression(italic("M. longa")), tag = "a)")+
  geom_segment(aes(y=y1+486*.2, x=x1-50+647*0.1, yend=y2+486*.2, xend=x2-50+647*0.1), size=1.5, data = mag_1.6)+
  annotate("text", x = 2*(826.02/5) + 647*0.1 + 100, y = 486*.2, label = "2 mm",parse=F,size=3,colour="black")+
  theme(axis.text.y = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.ticks.y =element_blank(),
        plot.title = element_text(size = 8, vjust = -13.5),
        panel.background = element_rect(fill = "white", colour = "white"),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        plot.margin = margin(-5, 1, -5, 1),
        plot.tag = element_text(size = 10),
        plot.tag.position=c(0.05,0.5))

### write figure 1, panels for b) and c) are produced in other scripts

# png(file = "Fig1.png",
#     width = 3.34646, height = 6, units = "in", pointsize = 2,res = 900,
#     bg = "white", type = c("cairo"))

pdf(file = "Fig1.pdf",
    width = 3.34646, height = 6)

(metridia_photo + finmarchicus_photo + glacialis_photo) / (metridia_map + finmarchicus_map + glacialis_map) / fig1c + plot_layout(guides = "collect") & theme(legend.position = "bottom")

dev.off()


