rm(list=ls())

library(dplyr)
library(ggplot2)
library(rworldmap)
library(geosphere)
library(sp)
library(raster)
library(sf)
library(smoothr)
library(scales)
library(data.table)
library(ggsci)
library(patchwork)
library(mapproj)
library(here)

############ Map for each species

metridia<-read.table("metridia.txt")
finmarchicus<-read.table("finmarchicus.txt")
glacialis<-read.table("glacialis.txt")

metridia$species<-"metridia"
finmarchicus$species<-"finmarchicus"
glacialis$species<-"glacialis"

worldMap <- getMap(resolution = "li") # "high"
world.points <- fortify(worldMap)
world.points$region <- world.points$id
world.df <- world.points[,c("long","lat","group", "region")]

add_NAs<-data.frame(long=c(NA,NA),lat=c(NA,NA),order=c(NA,NA),hole=c(NA,NA),piece=c(NA,NA),id=c(NA,NA),group=c(NA,NA),species=c("one","two"))
all_species<-rbind.data.frame(finmarchicus,add_NAs)

finmarchicus_map<-ggplot() + 
  geom_polygon(data = all_species, aes(x = long, y = lat, group = species, fill=species),alpha=0.8) +
  geom_polygon(data = world.df, aes(x = long, y = lat, group = group),color="gray", size=0.1) +
  scale_y_continuous(breaks = (-2:2) * 30) +
  scale_x_continuous(breaks = (-4:4) * 45) +
  coord_map("ortho", orientation=c(90, -90, 61)) + #, 
  scale_fill_aaas(name="Species:", labels=c(expression(italic("Metridia longa")), expression(italic("Calanus finmarchicus")), expression(italic("Calanus glacialis"))))+
  guides(fill=guide_legend(override.aes = list(fill=c(values = c("#008B45FF", "#3B4992FF", "#EE0000FF")),color="black"), ncol = 1))+
  # guides(fill="none")+ 
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),  
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        legend.text = element_text(size=10, hjust = 0), # left aligned
        legend.title = element_text(size = 10),
        legend.key.size = unit(20,"point"),
        legend.margin=margin(0,5,8,5),
        legend.box.margin=margin(-10,10,-3,10),
        legend.box.spacing = unit(0.5,"cm"),
        legend.position = "bottom",
        aspect.ratio = 1, plot.margin = margin(0, 1, 0, 1))


# g <- ggplot_build(finmarchicus_map)
# unique(g$data[[1]]["fill"])
# 
# 1   #008B45FF
# 138 #EE0000FF
# 139 #3B4992FF

glacialis_map<-ggplot() + 
  geom_polygon(data = glacialis, aes(x = long, y = lat, group = species), fill="#EE0000FF",alpha=0.8) +
  geom_polygon(data = world.df, aes(x = long, y = lat, group = group),color="gray", size=0.1) +
  scale_y_continuous(breaks = (-2:2) * 30) +
  scale_x_continuous(breaks = (-4:4) * 45) +
  coord_map("ortho", orientation=c(90, -90, 61)) + #, 
  guides(fill="none")+
  #scale_fill_aaas(name="Species", labels=c("C. finmarchicus","C. glacialis", "M. longa"))+
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),  
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.margin=margin(0,5,8,5),
        legend.box.margin=margin(-10,10,-3,10),
        legend.box.spacing = unit(0.5,"cm"),
        aspect.ratio = 1, plot.margin = margin(0, 1, 0, 1))

metridia_map<-ggplot() + 
  geom_polygon(data = metridia, aes(x = long, y = lat, group = species), fill="#008B45FF", alpha=0.8) +
  geom_polygon(data = world.df, aes(x = long, y = lat, group = group),color="gray", size=0.1) +
  scale_y_continuous(breaks = (-2:2) * 30) +
  scale_x_continuous(breaks = (-4:4) * 45) +
  coord_map("ortho", orientation=c(90, -90, 61)) + #, 
  guides(fill="none")+
  labs(tag = "b)")+
  #scale_fill_aaas(name="Species", labels=c("C. finmarchicus","C. glacialis", "M. longa"))+
  theme(axis.text.x = element_blank(),
        axis.text.y = element_blank(),  
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y = element_blank(),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.margin=margin(0,5,8,5),
        legend.box.margin=margin(-10,10,-3,10),
        legend.box.spacing = unit(0.5,"cm"),
        legend.position = "bottom",
        plot.tag = element_text(size = 10),
        plot.tag.position=c(0.05,0.5),
        aspect.ratio = 1, plot.margin = margin(0, 1, 0, 1))


