
rm(list=ls())

library(lme4)
library(car)
library(ggplot2)
library(tidyverse) 
library(lmerTest)
library(effects)
library(lubridate)
library(mclust)
library(ggsci)
library(patchwork)
library(xlsx)
library(Cairo)
library(here)

df_respiration<-read.table(file = "respiration_data_frame_temperature.txt")

df_respiration<-df_respiration[df_respiration$life_stage=="C5",] 
df_respiration$life_stage<-factor(df_respiration$life_stage)

df_respiration$slope<-df_respiration$slope * df_respiration$SDR_well_volume * 10^-6  # µmol

df_respiration$unique_ID<-factor(df_respiration$unique_ID)
df_respiration$individual<-factor(df_respiration$individual)
df_respiration$species<-factor(df_respiration$species)
df_respiration$station<-factor(df_respiration$station)
df_respiration$day_from_sampling_to_measurement<-as.numeric(df_respiration$day_from_sampling_to_measurement)

df_respiration$distance_from_atlantic<-NA
df_respiration$distance_from_atlantic[df_respiration$station=="BAB"]<-2
df_respiration$distance_from_atlantic[df_respiration$station=="ISG"]<-0
df_respiration$distance_from_atlantic[df_respiration$station=="ISK"]<-1

df_respiration$julian_date<-yday(df_respiration$measurement_day)

str(df_respiration)

rownames(df_respiration)<-c(1:nrow(df_respiration))

df_respiration<-subset(df_respiration, time<=70)

df_respiration<-subset(df_respiration, time>=5)

unique(df_respiration$unique_ID)

df_respiration_split<-split(df_respiration, df_respiration$individual)

mclust_models<-lapply(1:1719, function(x) densityMclust(df_respiration_split[[x]]$slope, verbose=FALSE))

table(unlist(lapply(1:1719, function(x) length(mclust_models[[x]]$parameters$mean))))

max_rates<-unlist(lapply(1:1719, function(x) min(mclust_models[[x]]$parameters$mean)))

min_rates<-unlist(lapply(1:1719, function(x) max(mclust_models[[x]]$parameters$mean)))

df_respiration<-data.frame(slope=c(max_rates, min_rates, max_rates-min_rates),
                              metabolic_measurement=rep(c("Max","Min","Scope"),c(1719,1719,1719)),
                              DW=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$dw[1])),3),
                              species=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$species[1])),3),
                              life_stage=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$life_stage[1])),3),
                              SDR_well_volume= rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$SDR_well_volume[1])),3),
                              individual=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$individual[1])),3),
                              unique_ID=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$unique_ID[1])),3),
                              distance_from_atlantic=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$distance_from_atlantic[1])),3),
                              station=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$station[1])),3),
                              individual=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$individual[1])),3),
                              temperature=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$temperature[1])),3),
                              julian_date=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$julian_date[1])),3),
                              measurement=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$measurement[1])),3),
                              measurement_time=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$measurement_time[1])),3),
                              day_from_sampling_to_measurement=rep(unlist(lapply(1:1719, function(x) df_respiration_split[[x]]$day_from_sampling_to_measurement[1])),3))

df_respiration1 <- df_respiration

table(df_respiration$slope<=0)

summary(df_respiration$slope)

# the response variable slope has very small values (µMol per minute) and is multiplied with a large constant 100000,
# the sign function is included to preserve the sign after log transformation, this to include all measurement errors, also when metabolic rate is positive even though impossible
# a 1 is added as constant for instances when metabolic rate is 0
# 100000 corresponds to 100000/(24*64) = approximately 65 days worth of respiration

# to convert to daily rates:
# scaling_factor <- (100000/(24*64))

df_respiration$slope <- sign(df_respiration$slope*100000) * log(abs(df_respiration$slope*100000) + 1)

max(df_respiration$DW)/min(df_respiration$DW)

############# create table 1

df_respiration_s <- split(df_respiration, interaction(df_respiration$species, df_respiration$station))

df_n_individuals <- data.frame(n_individuals = unlist(lapply(1:9, function (x) length(unique(df_respiration_s[[x]]$unique_ID)))),
           station = unlist(lapply(1:9, function (x) df_respiration_s[[x]]$station[1])),
           species = unlist(lapply(1:9, function (x) df_respiration_s[[x]]$species[1])))

df_n_individuals$station[df_n_individuals$n_individuals==0] <- "BAB"
df_n_individuals$species[df_n_individuals$n_individuals==0] <- "metridia"

df_n_individuals$station <- factor(df_n_individuals$station, levels=c("BAB", "ISK", "ISG"))

df_n_individuals<-df_n_individuals[order(df_n_individuals$station),]

##

df_respiration_temp_s <- split(df_respiration$unique_ID, interaction(df_respiration$species, df_respiration$station, df_respiration$temperature))

table_measurements <- sapply(df_respiration_temp_s, table)

unname(colSums(table_measurements))

string_split <- strsplit(names(colSums(table_measurements)), "\\.")

df_n_measurements <- data.frame(n_measurements = unname(colSums(table_measurements)),
                               station = unlist(lapply(1:27, function (x) string_split[[x]][2])),
                               species = unlist(lapply(1:27, function (x) string_split[[x]][1])),
                               temperature = unlist(lapply(1:27, function (x) paste0("measurements_", string_split[[x]][3]))))

wide_data <- spread(df_n_measurements, temperature, n_measurements)

wide_data$station <- factor(wide_data$station, levels=c("BAB", "ISK", "ISG"))

wide_data<-wide_data[order(wide_data$station),]

table_1 <- cbind.data.frame(df_n_individuals, wide_data)

table_1 <- table_1[,-c(4,5)]

str(table_1)

## min max and scope are 3 measurements:

table_1$measurements_0 <- paste0(table_1$measurements_0, " ", "(", round(table_1$measurements_0 / table_1$n_individuals / 3, 0), ")")

table_1$measurements_3 <- paste0(table_1$measurements_3, " ", "(", round(table_1$measurements_3 / table_1$n_individuals / 3, 0), ")")

table_1$measurements_6 <- paste0(table_1$measurements_6, " ", "(", round(table_1$measurements_6 / table_1$n_individuals / 3, 0), ")")

write.xlsx(table_1, "table_1.xlsx")

############# mixed model -- What are the hypotheses?

mod1<-lmer(slope ~ 
             station +
             measurement +
             measurement_time +
             log(DW) *  metabolic_measurement * temperature + # reduction in scope due to increasing RMR for increasing body mass, # includes body mass * temperature
             species *  metabolic_measurement * temperature + # different scope for species depending on temperature
             (temperature|species:unique_ID), 
           na.action = na.fail, 
           data = df_respiration, 
           REML=TRUE,
           control = lmerControl(optimizer ="Nelder_Mead"))

summary(mod1) # not meaningful for original scale parameters
Anova(mod1) # not meaningful for original scale parameters

plot(mod1)

# ######################################
# 
# ######################### plot histogram of dry weight, fig 1 c
# 
# ######################################

df_respiration_histogram_split<-split(df_respiration, df_respiration$unique_ID)

df_respiration_histogram<-data.frame(DW=unlist(lapply(1:179, function(x) df_respiration_histogram_split[[x]]$DW[1])),
                                     species=unlist(lapply(1:179, function(x) df_respiration_histogram_split[[x]]$species[1])),
                                     unique_ID=unlist(lapply(1:179, function(x) df_respiration_histogram_split[[x]]$unique_ID[1])))

fig1c<-ggplot(data = df_respiration_histogram, aes(x=DW, fill=species))+
  geom_histogram(binwidth = 0.5/11, alpha=0.6, position = "identity")+
  geom_density(alpha=0.8)+
  labs(y="Counts", x=expression("Dry weight individual"^-1~"(mg)"), title = "Size distribution", tag = "c)")+
  scale_fill_aaas(name="Species:", labels=c(expression(italic("Metridia longa")), expression(italic("Calanus finmarchicus")), expression(italic("Calanus glacialis"))))+
  guides(fill="none")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = 0.5),
        panel.grid = element_blank(),
        plot.tag.position = "topleft",
        panel.background = element_rect(fill = "white", colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical",
        legend.direction = "vertical",
        plot.margin = margin(0,2,0,0))

# # g <- ggplot_build(fig1a)
# # unique(g$data[[1]]["fill"])
# # 
# # 1  #3B4992FF
# # 30 #EE0000FF
# # 59 #008B45FF
# 
# png(file="fig1a.png", family = "Helvetica", res = 900, height = 4.5, width = 5, units = 'in')
# fig1a
# dev.off()

######################################

## three main effects station, repeated measurement, and measurement time

######################################

station_effect<-data.frame(Effect(c("station"), mod1))

lablabs <- c("BAB", "ISG", "ISK")

# conversion to daily rates 

scaling_factor <- (100000/(24*64))

fig5a<-ggplot(station_effect, aes(x=station, y=(exp(abs(fit)) - 1) / scaling_factor))+
  geom_point()+
  geom_pointrange(station_effect, mapping = aes(x=station, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor),
                  shape=21, fill="white")+
  scale_y_continuous(limits = c(0,0.2))+
  scale_x_discrete(labels = lablabs)+
  labs(x="Station", y=bquote('Metabolic rate,'~µmol~O[2]~day^-1), tag = "a)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = -2),
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        legend.key.width = unit(1.5,"cm"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  


measurement_effect<-data.frame(Effect(c("measurement"), mod1, xlevels = list(measurement = seq(from= 1, to =4, 0.1))))

fig5b<-ggplot(measurement_effect, aes(x=measurement, y=(exp(abs(fit)) - 1) / scaling_factor))+
  geom_line()+
  geom_ribbon(measurement_effect, mapping = aes(x=measurement, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor), alpha=0.4)+
  scale_y_continuous(limits = c(0,0.2))+
  labs(x="Repeated measurement", y=NULL, tag = "b)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = -2),
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        legend.key.width = unit(1.5,"cm"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  

measurement_time_effect<-data.frame(Effect(c("measurement_time"), mod1, xlevels = list(measurement_time = seq(from= 39, to =76, 1))))

fig5c<-ggplot(measurement_time_effect, aes(x=measurement_time, y=(exp(abs(fit)) - 1) / scaling_factor))+
  geom_line()+
  geom_ribbon(measurement_time_effect, mapping = aes(x=measurement_time, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor), alpha=0.4)+
  scale_y_continuous(limits = c(0,0.2))+
  labs(x="Measurement time (min)", y=NULL, tag = "c)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = -2),
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        legend.key.width = unit(1.5,"cm"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  

# png(file="Fig5.png", family = "Helvetica", res = 900, height = 2.3, width = 6, units = 'in')

pdf(file="Fig5.pdf", height = 2.3, width = 6)

fig5a + fig5b + fig5c

dev.off()


######################################

####### metabolic scope * temperature * species

######################################

######### finmarchicus

mean_DW<-mean(df_respiration$DW)

temperature_metabolic_measurement_F<-data.frame(Effect(c("temperature","metabolic_measurement","species","DW"), mod1, xlevels=list(temperature=seq(from=0,to=6,by=0.1),
                                                                                                                  DW=c(mean_DW,100,100))))

temperature_metabolic_measurement_F<-subset(temperature_metabolic_measurement_F, DW<=50)

temperature_metabolic_measurement_F<-subset(temperature_metabolic_measurement_F, species=="finmarchicus")

temperature_metabolic_measurement_F$species <- factor(temperature_metabolic_measurement_F$species)

fig3a<-ggplot(temperature_metabolic_measurement_F, aes(x=temperature, y=(exp(abs(fit)) - 1) / scaling_factor, linetype=metabolic_measurement))+
  geom_line(linewidth=0.8, color="#3B4992FF")+
  geom_line(temperature_metabolic_measurement_F[temperature_metabolic_measurement_F$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(lower)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color="#3B4992FF")+
  geom_line(temperature_metabolic_measurement_F[temperature_metabolic_measurement_F$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color="#3B4992FF")+
  geom_ribbon(temperature_metabolic_measurement_F[temperature_metabolic_measurement_F$metabolic_measurement!="Scope",], mapping = aes(x=temperature, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), fill="#3B4992FF", alpha=0.4)+
  scale_y_continuous(limits = c(0,0.53))+
  guides(linetype="none")+
  scale_linetype_manual(values = c("solid", "dashed", "dotted"))+
  labs(y=bquote('Metabolic rate,'~µmol~O[2]~day^-1), x="Temperature °C", linetype="Metabolic rate", title = expression(italic("Calanus finmarchicus")), tag="a)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "horizontal")  

############ glacialis

temperature_metabolic_measurement_G<-data.frame(Effect(c("temperature","metabolic_measurement","species","DW"), mod1, xlevels=list(temperature=seq(from=0,to=6,by=0.1),
                                                                                                                  DW=c(mean_DW,100,100))))

temperature_metabolic_measurement_G<-subset(temperature_metabolic_measurement_G, DW<=50)

temperature_metabolic_measurement_G<-subset(temperature_metabolic_measurement_G, species=="glacialis")

temperature_metabolic_measurement_G$species <- factor(temperature_metabolic_measurement_G$species)

fig3b<-ggplot(temperature_metabolic_measurement_G, aes(x=temperature, y=(exp(abs(fit)) - 1) / scaling_factor, linetype=metabolic_measurement))+
  geom_line(linewidth=0.8, color="#EE0000FF")+
  geom_line(temperature_metabolic_measurement_G[temperature_metabolic_measurement_G$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(lower)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color="#EE0000FF")+
  geom_line(temperature_metabolic_measurement_G[temperature_metabolic_measurement_G$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color="#EE0000FF")+
  geom_ribbon(temperature_metabolic_measurement_G[temperature_metabolic_measurement_G$metabolic_measurement!="Scope",], mapping = aes(x=temperature, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), inherit.aes = FALSE,fill="#EE0000FF", alpha=0.4)+
  scale_y_continuous(limits = c(0,0.53))+
  scale_linetype_manual(values = c("solid", "dashed", "dotted"), labels=c("AMR", "RMR", "Aerobic scope"))+
  guides(fill="none", linetype = guide_legend(override.aes = list(color = "black")))+
  labs(y=NULL, x="Temperature °C", linetype="Metabolic measurement:", title = expression(italic("Calanus glacialis")), tag="b)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        legend.key = element_rect(fill = "lightgray"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(1.5,"line"),
        legend.box = "horizontal")  

########### metridia

temperature_metabolic_measurement_M<-data.frame(Effect(c("temperature","metabolic_measurement","species","DW"), mod1, xlevels=list(temperature=seq(from=0,to=6,by=0.1),
                                                                                                                  DW=c(mean_DW,100,100))))

temperature_metabolic_measurement_M<-subset(temperature_metabolic_measurement_M, DW<=50)

temperature_metabolic_measurement_M<-subset(temperature_metabolic_measurement_M, species=="metridia")

temperature_metabolic_measurement_M$species <- factor(temperature_metabolic_measurement_M$species)

fig3c<-ggplot(temperature_metabolic_measurement_M, aes(x=temperature, y=(exp(abs(fit)) - 1) / scaling_factor, linetype=metabolic_measurement))+
  geom_line(linewidth=0.8, color= "#008B45FF")+
  geom_line(temperature_metabolic_measurement_M[temperature_metabolic_measurement_M$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(lower)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color= "#008B45FF")+
  geom_line(temperature_metabolic_measurement_M[temperature_metabolic_measurement_M$metabolic_measurement=="Scope",], mapping=aes(x=temperature, y=(exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), linetype="dotted", linewidth=0.5, color= "#008B45FF")+
  geom_ribbon(temperature_metabolic_measurement_M[temperature_metabolic_measurement_M$metabolic_measurement!="Scope",], mapping = aes(x=temperature, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=metabolic_measurement), fill= "#008B45FF", alpha=0.4)+
  scale_y_continuous(limits = c(0,0.53))+
  scale_linetype_manual(values = c("solid", "dashed", "dotted"))+
  guides(fill="none", linetype="none")+
  labs(y=NULL, x="Temperature °C", linetype="Metabolic measurement:", title = expression(italic("Metridia longa")), tag="c)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "horizontal")  


########## combine figures

# png(file="Fig3.png", family = "Helvetica", res = 900, height = 3.1, width = 6, units = 'in')

pdf(file="Fig3.pdf", height = 3.1, width = 6)

fig3a + fig3b + fig3c + plot_layout(guides = "collect") & theme(legend.position = "bottom", legend.box = "horizontal")

dev.off()

######################################

####### metabolic scope * DW * temperature - for each metabolic measurement

######################################

##### maximum metabolic rate, averaged over species

metabolic_measurement_DW_temperature<-data.frame(Effect(c("metabolic_measurement","DW","temperature"), mod1, xlevels=list(DW=seq(min(df_respiration$DW), max(df_respiration$DW), 0.01),
                                                                                                     temperature=c(0,3,6))))

metabolic_measurement_DW_temperature_max <- subset(metabolic_measurement_DW_temperature, metabolic_measurement=="Max")

metabolic_measurement_DW_temperature_max$metabolic_measurement <- factor(metabolic_measurement_DW_temperature_max$metabolic_measurement)

fig4a <-ggplot(metabolic_measurement_DW_temperature_max, aes(x=DW, y=(exp(abs(fit)) - 1) / scaling_factor, color=as.factor(temperature)))+
  geom_line(linewidth=0.8)+
  geom_line(metabolic_measurement_DW_temperature_max[metabolic_measurement_DW_temperature_max$temperature==3,], mapping = aes(x=DW, y=(exp(abs(lower)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_line(metabolic_measurement_DW_temperature_max[metabolic_measurement_DW_temperature_max$temperature==3,], mapping = aes(x=DW, y=(exp(abs(upper)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_ribbon(metabolic_measurement_DW_temperature_max[metabolic_measurement_DW_temperature_max$temperature!=3,], 
              mapping = aes(x=DW, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=as.factor(temperature), fill=as.factor(temperature)), 
              inherit.aes = FALSE, alpha=0.4)+
  geom_point(df_respiration_histogram, mapping =  aes(x=DW, y=-0.01), inherit.aes = FALSE, size=1, shape="I")+
  scale_y_continuous(limits = c(-0.01,0.7))+
  scale_x_continuous(breaks = c(0,0.6,1.2))+
  scale_color_manual(values = c("#008EA0FF", "#FF6F00FF", "#C71000FF"))+
  scale_fill_manual(values = c("#008EA0FF", "#C71000FF"))+
  guides(fill="none", color="none")+
  labs(y=bquote('Metabolic rate,'~µmol~O[2]~day^-1), x="Dry weight (mg)",color="Temperature °C:", title = "Active metabolic rate", tag="a)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  

##### minimum metabolic rate, averaged over species

metabolic_measurement_DW_temperature_min <- subset(metabolic_measurement_DW_temperature, metabolic_measurement=="Min")

metabolic_measurement_DW_temperature_min$metabolic_measurement <- factor(metabolic_measurement_DW_temperature_min$metabolic_measurement)

fig4b<-ggplot(metabolic_measurement_DW_temperature_min, aes(x=DW, y=(exp(abs(fit)) - 1) / scaling_factor, color=as.factor(temperature)))+
  geom_line(linewidth=0.8)+
  geom_line(metabolic_measurement_DW_temperature_min[metabolic_measurement_DW_temperature_min$temperature==3,], mapping = aes(x=DW, y=(exp(abs(lower)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_line(metabolic_measurement_DW_temperature_min[metabolic_measurement_DW_temperature_min$temperature==3,], mapping = aes(x=DW, y=(exp(abs(upper)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_ribbon(metabolic_measurement_DW_temperature_min[metabolic_measurement_DW_temperature_min$temperature!=3,], 
              mapping = aes(x=DW, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=as.factor(temperature), fill=as.factor(temperature)), 
              inherit.aes = FALSE, alpha=0.4)+
  geom_point(df_respiration_histogram, mapping =  aes(x=DW, y=-0.01), inherit.aes = FALSE, size=1, shape="I")+
  scale_y_continuous(limits = c(-0.01,0.7))+
  scale_x_continuous(breaks = c(0,0.6,1.2))+
  scale_color_manual(values = c("#008EA0FF", "#FF6F00FF", "#C71000FF"))+
  scale_fill_manual(values = c("#008EA0FF", "#C71000FF"))+
  guides(fill="none")+
  labs(y=NULL, x="Dry weight (mg)",color="Temperature °C:", title = "Resting metabolic rate", tag="b)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        legend.key = element_rect(fill = "lightgray"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  

##### metabolic scope, averaged over species

metabolic_measurement_DW_temperature_scope <- subset(metabolic_measurement_DW_temperature, metabolic_measurement=="Scope")

metabolic_measurement_DW_temperature_scope$metabolic_measurement <- factor(metabolic_measurement_DW_temperature_scope$metabolic_measurement)

fig4c<-ggplot(metabolic_measurement_DW_temperature_scope, aes(x=DW, y=(exp(abs(fit)) - 1) / scaling_factor, color=as.factor(temperature)))+
  geom_line(linewidth=0.8)+
  geom_line(metabolic_measurement_DW_temperature_scope[metabolic_measurement_DW_temperature_scope$temperature==3,], mapping = aes(x=DW, y=(exp(abs(lower)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_line(metabolic_measurement_DW_temperature_scope[metabolic_measurement_DW_temperature_scope$temperature==3,], mapping = aes(x=DW, y=(exp(abs(upper)) - 1) / scaling_factor, color=as.factor(temperature)), linetype="dotted", size=0.5)+
  geom_ribbon(metabolic_measurement_DW_temperature_scope[metabolic_measurement_DW_temperature_scope$temperature!=3,], 
              mapping = aes(x=DW, ymin = (exp(abs(lower)) - 1) / scaling_factor, ymax = (exp(abs(upper)) - 1) / scaling_factor, group=as.factor(temperature), fill=as.factor(temperature)), 
              inherit.aes = FALSE, alpha=0.4)+
  geom_point(df_respiration_histogram, mapping =  aes(x=DW, y=-0.01), inherit.aes = FALSE, size=1, shape="I")+
  scale_y_continuous(limits = c(-0.01,0.7))+
  scale_x_continuous(breaks = c(0,0.6,1.2))+
  scale_color_manual(values = c("#008EA0FF", "#FF6F00FF", "#C71000FF"))+
  scale_fill_manual(values = c("#008EA0FF", "#C71000FF"))+
  guides(fill="none", color="none")+
  labs(y=NULL, x="Dry weight (mg)",color="Temperature °C:", title = "Aerobic scope", tag="c)")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_blank(),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10), # , hjust = 0, vjust = -2
        # panel.grid = element_blank(),
        # plot.tag.position = c(0.01,0.98),
        panel.background = element_rect(colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  

########## combine figures

# png(file="Fig4.png", family = "Helvetica", res = 900, height = 3, width = 6, units = 'in')

pdf(file="Fig4.pdf", height = 3, width = 6)

fig4a + fig4b + fig4c  + plot_layout(guides = "collect") & theme(legend.position = "bottom", legend.box = "horizontal")

dev.off()

######

# comparison of metabolic rates with two other studies based on the average mass of copepods in this study

######

mean(df_respiration_histogram$DW)

# comparison with Ingvarsdóttir et al 1999
# Ingvarsdóttir, A., Houlihan, D. F., Heath, M. R., & Hay, S. J. (1999). 
# Seasonal changes in respiration rates of copepodite stage V Calanus finmarchicus (Gunnerus). 
# Fisheries Oceanography, 8, 73-83. https://doi.org/10.1046/j.1365-2419.1999.00002.x 

(0.621*mean(df_respiration_histogram$DW)) - 0.0186 # 0.197 mg Carbon

(20 / 1000) # µmol O2 g carbon hour # the number 20 is from Figure 4 January values

(20 / 1000) * 24 # µmol O2 mg carbon day

((20 / 1000) * 24) * (0.197/1) # µmol O2 mg carbon day standardized after our average-sized individual

# comparison with Ikeda et al 1999:
# Ikeda, T., Kanno, Y., Ozaki, K., & Shinada, A. (2001). 
# Metabolic rates of epipelagic marine copepods as a function 
# of body mass and temperature. Marine Biology, 139, 587-596.
# https://doi.org/10.1007/s002270100608 

# female Metridia longa according to Ikeda 2001 use:
# 0.406 µL O2 and weigh 0.353 mg
# standardize after our mean individual:
0.406 * (mean(df_respiration_histogram$DW) / 0.353) # 0.398 µL O2

# IUPAC revised STP definition of ideal gas
# 1 µmol O2 = 0.022391 ml O2
# 1 μmol = 22.391 μl

# convert to µMol per day:
# (0.398/22.391) * 24 = 0.4266 µMol per ind of average size and day

# female Calanus finmarchicus according to Ikeda 2001
# 0.328 µL O2 and weigh 0.387 mg
0.382 * (mean(df_respiration_histogram$DW) / 0.387) # 0.342 µL O2

# convert to µMol per day:
# (0.342/22.391) * 24 = 0.367 µMol per ind of average size and day

# female Calanus glacialis according to Ikeda 2001
# 0.616 µL O2 and weigh 0.474 mg
0.616 * (mean(df_respiration_histogram$DW) / 0.474) # 0.450 µL O2

# convert to µMol per day:
# (0.450/22.391) * 24 = 0.482 µMol per ind of average size and day

