
rm(list=ls())

library(marmap)
library(ggplot2) 
library(tidyverse)
library(patchwork)
library(xlsx)
library(sf)
library(rworldmap)
library(ggrepel)
library(png)
library(grid)
library(smoothr)

##### Include the number of individuals sampled at each station

df_sampling_stations <- data.frame(x =c(16.355256, 15.154920, 14.005250), y = c(78.536519, 78.318222, 78.154337), label = c("Billefjorden", "Karlskronadjupet", "Grønfjorden"))

df_sampling_stations_sf <- st_as_sf(df_sampling_stations, coords = c("x", "y"))

st_crs(df_sampling_stations_sf) <- st_crs(4326)

########### Map of Northern Europe

worldMap <- getMap(resolution = "high") # "high"

worldMap<-st_as_sf(worldMap)

worldMap<-worldMap[,c("ADMIN.1", "geometry")]

select_countries<-c("Sweden", "Finland", "Norway", "Faroe Islands", "Aland","Iceland", "Greenland", "Kazakhstan", "Moldova", "Hungary", "Ireland", "Denmark", "Estonia", "Russia", "Latvia", "Lithuania", "Germany", "Poland", "Belarus", "Netherlands", "United Kingdom", "France", "Ukraine", "Belgium", "Austria", "Luxembourg", "Czech Republic", "Slovakia")

worldMap<-worldMap[worldMap$ADMIN.1 %in% select_countries,]

worldMap<-drop_crumbs(worldMap, threshold = 54015369)

options(scipen=10000)

### Sea names

sea_names<-data.frame(Name=c("Barents Sea", "West\nSpitsbergen\nCurrent", "Arctic Ocean"),
                      y=c(76.209657, 76.677006, 81.779561),
                      x=c(20.711235, 10.270799, 19.163587))

sea_names<-st_as_sf(sea_names, coords = c("x", "y"))

st_crs(sea_names)<-st_crs(4326)

theme_set(theme_bw()) # needed to create a border framing the map

Bathy1 <- getNOAA.bathy(lon1 = 6, lon2 = 29,
                       lat1 = 75, lat2 = 82, resolution = 1)

Bathy1 <- as.xyz(Bathy1)

Svalbard_map <- ggplot()+
  geom_sf(data = worldMap, color="black", fill = NA, size=0.1)+
  geom_contour(data = Bathy1, 
               aes(x = V1, y = V2, z = V3),
               binwidth = 100, color = "grey85", size = 0.1) +
  geom_contour(data = Bathy1, 
               aes(x = V1, y = V2, z = V3),
               breaks = -200, color = "grey85", size = 0.5) +
  geom_sf(data = worldMap, color="black", fill = NA, size=0.1)+ # fill = NULL,
  geom_text(data = sea_names, aes(geometry = geometry, label=Name),
            stat = "sf_coordinates", size=4, alpha=0.9, color="darkblue")+
  geom_label_repel(data = df_sampling_stations_sf, aes(geometry = geometry, label=label),
                   stat = "sf_coordinates", size=3, alpha=0.9, nudge_x = -1, min.segment.length = unit(0, 'lines'))+
  geom_point(data = df_sampling_stations_sf, aes(geometry = geometry), color = "red",
                   stat = "sf_coordinates", size=2)+
  coord_sf(ylim = c(75,82), xlim = c(6,29), expand = FALSE)+
  scale_y_continuous("Northing")+
  scale_x_continuous("Easting")+
  guides(fill = "none")+
  # labs(size = "Number of\ntransported eels")+
  theme(panel.background = element_rect(color = "black"), # fill = "lightblue", 
        panel.grid = element_blank(),
        legend.position = "bottom",  # c(0.2, 0.2)
        #legend.box = "vertical",
        #legend.spacing.y = unit(-2.0, 'mm'),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.background=element_rect(fill = "lightgray"),
        legend.key=element_blank())

ymin<-75
ymax<-82

xmin<-6
xmax<-29

sfc = st_sfc(st_polygon(list(rbind(c(xmin,ymin), c(xmax,ymin), c(xmax,ymax), c(xmin,ymax), c(xmin,ymin)))))

st_crs(sfc)<-st_crs(4326)

Bathy2 <- getNOAA.bathy(lon1 = -35, lon2 = 50,
                        lat1 = 50, lat2 = 85, resolution = 50)

Bathy2 <- as.xyz(Bathy2)

# inset_TT_map<-

inset_Svalbard_map<- ggplot()+
  geom_sf(data = worldMap, color="black", fill = NA, size=0.0001)+
  # geom_contour(data = Bathy2, 
  #              aes(x = V1, y = V2, z = V3),
  #              binwidth = 100, color = "grey85", size = 0.1) +
  # geom_contour(data = Bathy2, 
  #              aes(x = V1, y = V2, z = V3),
  #              breaks = -200, color = "grey85", size = 0.5) +
  # geom_sf(data = worldMap, color="black", fill = NA, size=0.0001)+ # fill = NULL,
  geom_sf(data = sfc, color="black", size=0.5, fill=NA)+
  coord_sf(ylim = c(52,83), xlim = c(-31,46))+
  scale_y_continuous("Northing")+
  scale_x_continuous("Easting")+
  guides(fill = "none")+
  theme(panel.background = element_rect(fill = "lightyellow", colour ="black", size = 0.5),
        panel.grid = element_blank(),
        plot.background = element_blank(),
        panel.border = element_blank(),
        legend.position = c(0.2, 0.2),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        # plot.margin = c(0,0,0,0, 'cm'), ###### fix later
        # legend.box = "vertical",
        # legend.spacing.y = unit(-2.0, 'mm'),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.background=element_rect(fill = "lightgray"),
        legend.key=element_blank())


# png(file="Fig2.png", family = "Helvetica", res = 900, height = 5, width = 3.34646, units = 'in', type = "cairo")

pdf(file="Fig2.pdf", height = 5, width = 3.34646)

grid.newpage()

v1<-viewport(width = 1, height = 1, x = 0.5, y = 0.5) #plot area for the main map
v2<-viewport(width = 0.3, height = 0.3, x = 0.7, y = 0.75) #plot area for the inset map

print(Svalbard_map,vp=v1) 
print(inset_Svalbard_map,vp=v2)

dev.off()

