
rm(list=ls())

library(zoo)
library(data.table)
library(reshape2)
library(here)

#############

### parameters

#############

n_readings<-96 # this is the number of sensor dish readings

n_wells<-96*24 # this is the number of measurements 24 per reading, i.e. 24 wells per dish

n_wells_t<-96*20 # this is the number of measured animals 20 per reading as there were 4 controls/ blank wells per reading

#############

### Read in respiration files

#############

filenames_respiration <- list.files(pattern="*.Rdata", full.names=FALSE)

#filenames_respiration<-filenames_respiration[order(nchar(filenames_respiration),filenames_respiration)]

myfun <- function(x){
  df <- get(load(x))[[7]][,c(5:28,77)]
}

Rdata_files <- lapply(filenames_respiration,myfun)

Rdata_files_stacked<-lapply(1:n_readings, function (x) stack(Rdata_files[[x]][-25]))

reading <- paste0(rep("reading",n_readings),1:n_readings)

# Add information about the reading so that all files can be merged

readings <- lapply(1:n_readings, function (i) rep(reading[i],nrow(Rdata_files_stacked[[i]])))

# Make 'time' into long format

times <- lapply(1:n_readings, function (i) rep(Rdata_files[[i]]$time_in_minutes,24))

# Merge files

respiration_data<-do.call(rbind,Rdata_files_stacked)

# Add reading, time, and individual ID to the data frame

respiration_data$reading<-unlist(readings)

respiration_data$time<-unlist(times)

respiration_data$unique_well<-paste0(respiration_data$ind,"_",respiration_data$reading)

str(respiration_data)

# Change column names

colnames(respiration_data)<-c("phase","well","reading","time","unique_well")

# Create a numeric unique ID, this is important for the split() function to work properly later on

a<-unique(respiration_data$unique_well)

b<-lapply(1:n_wells, function (i) length(respiration_data$unique_well[respiration_data$unique_well==a[i]]))

respiration_data$unique_well_num<-rep(1:n_wells,unlist(b))

################ subset data ##########################

# We are interested in the 0 to 75 minutes of measurement. 

respiration_data<-respiration_data[respiration_data$time<=76,] 

# respiration_data<-respiration_data[respiration_data$time<=45 | respiration_data$reading!="reading5",]
# 
# respiration_data<-respiration_data[respiration_data$time<=55 | respiration_data$reading!="reading24",]
# 
# respiration_data<-respiration_data[respiration_data$time<=55 | respiration_data$reading!="reading42",]
# 
# respiration_data<-respiration_data[respiration_data$time<=65 | respiration_data$reading!="reading51",]
# 
# respiration_data<-respiration_data[respiration_data$time<=45 | respiration_data$unique_well_num!=535,]
# 
# respiration_data<-respiration_data[respiration_data$time<=45 | respiration_data$unique_well_num!=868,]


################

## Read in calibration files

################

# Read in and rearrange the calibration data from wide to long format, there is one file per reading

filenames_Rdatafiles_respiration <- list.files(pattern="*.Rdata", full.names=FALSE)

#filenames_Rdatafiles_respiration<-filenames_Rdatafiles_respiration[order(nchar(filenames_Rdatafiles_respiration),filenames_Rdatafiles_respiration)]

All_readings_calibration<-paste0(rep("All_readings",n_readings),1:n_readings)

for (i in 1:n_readings) {
  All_readings_calibration[i]<-get(load(filenames_Rdatafiles_respiration[i]))[6]
}

All_readings_calibration<-rbindlist(All_readings_calibration)

All_readings_calibration[1:n_wells]

###############

## models

###############

time_resp<-split(respiration_data, respiration_data$unique_well_num)

models<-lapply(split(respiration_data, respiration_data$unique_well_num), 'lm', formula=  phase~  poly(time+1,1)+log(time+1))

########## predict ###########################

# Create a data frame for predictions that goes up to at least 76 minutes with
# an observation for every 15 second (0.25 min) and add information about which well it is

# Calculate the time for each respiration measurement and save for later 
max_time<-unlist(lapply(1:n_wells, function(x) max(time_resp[[x]]$time)))

median(max_time)

my_newdata<-lapply(1:n_wells, function(x) seq(0,76,0.25)) # make all predictions the same length

newData<-data.frame(unlist(my_newdata))

newData$well<-rep(unique(respiration_data$unique_well_num), lengths(my_newdata))

n_observations_per_well<-lengths(my_newdata)

n_observations_per_reading<-split(n_observations_per_well, cut(seq_along(n_observations_per_well), n_readings, labels = FALSE)) 

sum_n_observations_per_reading<-lapply(1:96, function(x) sum(n_observations_per_reading[[x]]))

colnames(newData)<-c("time", "well")

# Predict and create a data frame of predictions

pred_models  <- mapply('predict', models, split(newData, newData$well), se.fit=TRUE)

pred_data<-data.frame(phase=unlist(pred_models[c(seq(1,96*96,4))]), time=newData$time, well=newData$well, 
                      reading=rep(c(1:96), unlist(sum_n_observations_per_reading)))

################## plot #####################

wells<-paste0(unique(respiration_data$unique_well),"__",c(1:2304))

# for(i in c(96:2304)){
#   b<-split(pred_data, pred_data$well)
#   plot(b[[i]]$time, b[[i]]$phase, main = print(wells[i]))
#   points(time_resp[[i]]$time,time_resp[[i]]$phase, col="red")
#   browser()
# }

#################

#### Add calibration data and calculate O2

#################

str(pred_data)

the_wells<-unique(pred_data$well)

n_measurements<-lapply(1:n_wells, function (i) length(pred_data$well[pred_data$well==the_wells[i]]))

pred_data$phase_L<-rep(All_readings_calibration$phase_L,unlist(n_measurements))

pred_data$phase_H<-rep(All_readings_calibration$phase_H,unlist(n_measurements))

pred_data$temperature<-rep(All_readings_calibration$temperature,unlist(n_measurements))

head(pred_data)

s<-split(pred_data,pred_data$reading)

# the pattern indicate that temperature was added in the correct order
unlist(lapply(1:96, function(x) mean(s[[x]]$temperature))) 

#################

#### Calculate average O2 of the control wells  

#################

# There are 4 control wells per reading, this code calculates the average O2 per reading at time t

pred_data$muMol<-NA

pred_data$muMol[pred_data$temperature==0]<-349.5601
pred_data$muMol[pred_data$temperature==3]<-323.6122
pred_data$muMol[pred_data$temperature==6]<-300.8798

pred_data$O2<-(pred_data$phase_L - pred_data$phase)*(pred_data$muMol/(pred_data$phase_L - pred_data$phase_H))

A3<-lapply( seq(3,n_wells,24),function (i) pred_data$O2[pred_data$well==i ])
B4<-lapply( seq(10,n_wells,24),function (i) pred_data$O2[pred_data$well==i ])
C1<-lapply( seq(13,n_wells,24),function (i) pred_data$O2[pred_data$well==i ])
D2<-lapply( seq(20,n_wells,24),function (i) pred_data$O2[pred_data$well==i ])

controls<-list(A3,B4,C1,D2)

reading_and_control<-lapply(1:n_readings, function (x) list(A3=controls[[1]][[x]],B4=controls[[2]][[x]],C1=controls[[3]][[x]],D2=controls[[4]][[x]]))

pred_data_control <-lapply(1:n_readings, function (i) unlist(lapply(transpose(reading_and_control[[i]]), mean, na.rm=TRUE))) # average O2 values per reading

pred_data_control<-lapply(1:n_readings, function (x) rep(pred_data_control[x],24)) # repeat the averages 24 times for each reading

pred_data_control<-unlist(pred_data_control,recursive = FALSE) # one list of all control averages

pred_data_control_diff<-lapply(1:n_wells, function (i) pred_data_control[[i]] - pred_data_control[[i]][1]) # difference in O2 from first measurement

#####################

### subtract the control respiration from the copepod respiration

#####################

pred_data_split<-split(pred_data, factor(pred_data$well))

n_observations<-lengths(lapply(1:n_wells, function(i) pred_data_split[[i]]$phase))

pred_data$O2_control<-unlist(lapply(1:n_wells, function(i) pred_data_control_diff[[i]][1:n_observations[i]])) # add control O2 values

pred_data$respiration<-(pred_data$O2-pred_data$O2_control)

###################

######## Remove control wells

###################

select_wells<-c(seq(3,n_wells,24),seq(10,n_wells,24), seq(13,n_wells,24), seq(20,n_wells,24))

`%notin%` <- Negate(`%in%`)

pred_data<-pred_data[pred_data$well %notin% select_wells,]

#################

## Select the region to measure respiration  

#################

# c1<-split(pred_data, factor(pred_data$well))
# 
# d1<-lapply(1:n_wells_t, function (i) subset(c1[[i]], time <= 45 )) #
# 
# d2<-lapply(1:n_wells_t, function (i) subset(d1[[i]], time >= 0 )) #
# 
# length(seq(31.75,36.5,.25)) # 20
# 
# head(pred_data)
# 
# pred_data<-data.frame(respiration=unlist(lapply(1:n_wells_t, function (x) d2[[x]]$respiration)), time=unlist(lapply(1:n_wells_t, function (x) d2[[x]]$time)), well=unlist(lapply(1:n_wells_t, function (x) d2[[x]]$well)))

pred_data<-data.frame(respiration=pred_data$respiration, time=pred_data$time, well=pred_data$well)

#################

#### Run the rolling regression analysis

#################

# Prepare the data for the rolling regression

pred_data_split<-split(pred_data[,c(-3)], pred_data$well)

str(pred_data_split)

pred_zoo_data<-lapply(1:n_wells_t,function  (x) zoo(pred_data_split[[x]]))

str(pred_zoo_data)

# Check the number of observations, they differ between readings

table(unlist(lapply(1:n_wells_t, function(i) nrow(pred_zoo_data[[i]])))) # n_observations

# Check how long time (minutes) there is predicted data for each animal, they differ between readings

unlist(lapply(1:n_wells_t, function (i) round(nrow(pred_zoo_data[[i]]))))*0.25 # minutes of measurements per animal in the specified region

# Run the rolling regression analysis, width 20 means regressions of five minutes each, that is, 20 * 0.25 = 5

rolling_regression_data <- lapply(1:n_wells_t, function(i) rollapply(pred_zoo_data[[i]], width=20,
                                                                     FUN = function(d) coef(lm(respiration ~ time, data = as.data.frame(d))), 
                                                                     fill = NA,by.column = F,align = "left"))


#################

#### Create a data frame of respiration values and information about the individual

#################


############ add information about the individual

information_about_the_individual <- list.files(pattern="*.csv", full.names=FALSE)

information_about_the_individual<-lapply(information_about_the_individual,read.csv,header=TRUE)

temperatures<-3

repeated_measurements<-c(4,3,3,3,3,4,3,3,3,3)

information_about_the_individual<-lapply(1:10, function(x) replicate(temperatures*repeated_measurements[x],information_about_the_individual[[x]],simplify = F))

information_about_the_individual<-rbindlist(unlist(information_about_the_individual, recursive = F))

information_about_the_individual$Species[information_about_the_individual$Species==""] <-NA
information_about_the_individual$Life_stage[information_about_the_individual$Life_stage==""] <-NA
information_about_the_individual$X96_well[information_about_the_individual$X96_well==""] <-NA

unique(information_about_the_individual$Species) #OK
unique(information_about_the_individual$Life_stage) #OK
unique(information_about_the_individual$X96_well) #OK
unique(information_about_the_individual$Plate) #OK
unique(information_about_the_individual$Station) #OK

information_about_the_individual$unique_ID<-paste0(information_about_the_individual$X96_well,information_about_the_individual$Plate)

information_about_the_individual$measurement<-c(rep(rep(c(1,2,3,4),c(20,20,20,20)),3),
rep(rep(c(1,2,3),c(20,20,20)),4*3),
rep(rep(c(1,2,3,4),c(20,20,20,20)),3),
rep(rep(c(1,2,3),c(20,20,20)),4*3))

information_about_the_individual$temperature<-rep(rep(c(0,3,6),10),rep(c(4,3,3,3,3,4,3,3,3,3),rep(3,10))*20)

############## read dw (dry weight) file ##############

dw<-list.files(pattern="*_dw.txt", full.names=FALSE)

dw<-lapply(dw,read.table,header=T)

dw<-rbindlist(dw)

dw$unique_ID<-paste0(dw$well,dw$plate)

str(information_about_the_individual)

information_about_the_individual$individual<-1:1920

## remove control wells from max time data

max_time<-data.frame(max_time=max_time)

max_time$well <- 1:nrow(max_time)

max_time<-max_time[max_time$well %notin% select_wells,]

information_about_the_individual$measurement_time <- max_time$max_time

s1<-split(information_about_the_individual,information_about_the_individual$individual)

n_coeff<-lengths(lapply(1:n_wells_t, function(x) na.omit(rolling_regression_data[[x]])))/2

## make df

df<-data.frame(slope=unlist(lapply(1:1920,function(x) rolling_regression_data[[x]]$time[1:n_coeff[x]])), 
               time=unlist(lapply(1:1920, function(x) seq(0,205,0.25)[1:n_coeff[x]])),
               individual=rep(1:1920,n_coeff),
               temperature=unlist(lapply(1:1920, function(x) rep(s1[[x]]$temperature[1],n_coeff[x]))),
               species=unlist(lapply(1:1920, function(x) rep(s1[[x]]$Species[1],n_coeff[x]))),
               life_stage=unlist(lapply(1:1920, function(x) rep(s1[[x]]$Life_stage[1],n_coeff[x]))),
               measurement=unlist(lapply(1:1920, function(x) rep(s1[[x]]$measurement[1],n_coeff[x]))),
               measurement_time=unlist(lapply(1:1920, function(x) rep(s1[[x]]$measurement_time[1],n_coeff[x]))),
               unique_ID=unlist(lapply(1:1920, function(x) rep(s1[[x]]$unique_ID[1],n_coeff[x]))),
               well_96=unlist(lapply(1:1920, function(x) rep(s1[[x]]$X96_well[1],n_coeff[x]))),
               plate_dry_weight=unlist(lapply(1:1920, function(x) rep(s1[[x]]$Plate[1],n_coeff[x]))),
               station=unlist(lapply(1:1920, function(x) rep(s1[[x]]$Station[1],n_coeff[x]))),
               SDR_well=unlist(lapply(1:1920, function(x) rep(s1[[x]]$SDR_well[1],n_coeff[x]))),
               SDR_well_volume=500,
               magnification_photo=1.6)

df<-merge(dw, df, by="unique_ID")

df<-as.data.frame(df)

####################

#### remove some measurements where the individual got lost

####################

# B11

B11<-df[df$unique_ID=="B11" & df$measurement==1 & df$temperature==0,]

as.numeric(rownames(B11)) # 74040, 74240 

df<-df[-c(as.numeric(rownames(B11))),]

rownames(df)<-1:nrow(df)

df$measurement[df$unique_ID=="B11" & df$measurement==2 & df$temperature==0]<-1
df$measurement[df$unique_ID=="B11" & df$measurement==3 & df$temperature==0]<-2
df$measurement[df$unique_ID=="B11" & df$measurement==4 & df$temperature==0]<-3

# B61

B61<-df[df$unique_ID=="B61" & df$measurement==1 & df$temperature==0,]

as.numeric(rownames(B61)) # 111139, 111339

df<-df[-c(as.numeric(rownames(B61))),]

rownames(df)<-1:nrow(df)

df$measurement[df$unique_ID=="B61" & df$measurement==2 & df$temperature==0]<-1
df$measurement[df$unique_ID=="B61" & df$measurement==3 & df$temperature==0]<-2
df$measurement[df$unique_ID=="B61" & df$measurement==4 & df$temperature==0]<-3

# F61

F61<-df[df$unique_ID=="F61" & df$measurement==3 & df$temperature==6,]

as.numeric(rownames(F61)) # 271742, 271942

df<-df[-c(as.numeric(rownames(F61))),]

rownames(df)<-1:nrow(df)

# check

length(unique(df$unique_ID[df$species=="finmarchicus" & df$station=="BAB"])) # should be 18 -OK

###################

## days between sampling and measurement

###################

df$sampling_date<-NA
df$sampling_date[df$station=="BAB"]<-"2020/09/16"
df$sampling_date[df$station=="ISG"]<-"2020/09/14"
df$sampling_date[df$station=="ISK"]<-"2020/10/02"
df$sampling_date[df$station=="ISK2"]<-"2020/10/02"

df$measurement_day<-NA
df$measurement_day[df$station=="BAB" & df$temperature==0]<-"2020/09/17"
df$measurement_day[df$station=="BAB" & df$temperature==3]<-"2020/09/18"
df$measurement_day[df$station=="BAB" & df$temperature==6]<-"2020/09/19"

df$measurement_day[df$station=="ISK" & df$temperature==0 & df$measurement==1]<-"2020/10/14"
df$measurement_day[df$station=="ISK" & df$temperature==0 & df$measurement==2]<-"2020/10/14"
df$measurement_day[df$station=="ISK" & df$temperature==0 & df$measurement==3]<-"2020/10/15"
df$measurement_day[df$station=="ISK" & df$temperature==3]<-"2020/10/16"
df$measurement_day[df$station=="ISK" & df$temperature==6]<-"2020/10/17"

df$measurement_day[df$station=="ISK2" & df$temperature==0]<-"2020/10/20"
df$measurement_day[df$station=="ISK2" & df$temperature==3]<-"2020/10/21"
df$measurement_day[df$station=="ISK2" & df$temperature==6]<-"2020/10/22"

df$measurement_day[df$station=="ISG" & df$temperature==0 & df$species=="finmarchicus"]<-"2020/09/20"
df$measurement_day[df$station=="ISG" & df$temperature==3 & df$species=="finmarchicus"]<-"2020/09/21"
df$measurement_day[df$station=="ISG" & df$temperature==6 & df$species=="finmarchicus"]<-"2020/09/22"

df$measurement_day[df$station=="ISG" & df$temperature==0 & df$species=="glacialis"]<-"2020/09/20"
df$measurement_day[df$station=="ISG" & df$temperature==3 & df$species=="glacialis"]<-"2020/09/21"
df$measurement_day[df$station=="ISG" & df$temperature==6 & df$species=="glacialis"]<-"2020/09/22"

df$measurement_day[df$station=="ISG" & df$temperature==0 & df$species=="metridia"]<-"2020/09/26"
df$measurement_day[df$station=="ISG" & df$temperature==3 & df$species=="metridia"]<-"2020/09/27"
df$measurement_day[df$station=="ISG" & df$temperature==6 & df$species=="metridia"]<-"2020/09/28"

df$station[df$station=="ISK2"]<-"ISK"

df$sampling_date<-as.Date(df$sampling_date, format="%Y/%m/%d")
df$measurement_day<-as.Date(df$measurement_day, format="%Y/%m/%d")

df$day_from_sampling_to_measurement<-as.Date(df$measurement_day, format="%Y/%m/%d")-as.Date(df$sampling_date, format="%Y/%m/%d")

nrow(df[df$unique_ID=="A102" & df$temperature==0 & df$measurement==3,])

# write table

write.table(df[,-5], file = "respiration_data_frame_temperature.txt")

###################

#### correlation

###################

#rm(list=ls())

respiration_df<-read.table(file = "respiration_data_frame_temperature.txt")

########################## calculate respiration

respiration_df$slope<-respiration_df$slope * respiration_df$SDR_well_volume * 10^-6  # ?mol

min(respiration_df$slope)

max(respiration_df$slope)

#### overall correlation

respiration_df_s<-split(respiration_df, interaction(respiration_df$time, respiration_df$temperature, respiration_df$unique_ID))

df<-data.frame(slope=unlist(lapply(1:160446, function(x) mean(respiration_df_s[[x]]$slope))),
               temperature=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$temperature[1])),
               unique_ID=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$unique_ID[1])),
               station=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$station[1])),
               dw=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$dw[1])),
               species=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$species[1])),
               time=unlist(lapply(1:160446, function(x) respiration_df_s[[x]]$time[1])))

df<-na.omit(df)

df_s<-split(df, df$time)

correlations<-unlist(lapply(1:286, function(x) cor.test(log(df_s[[x]]$dw),log(df_s[[x]]$slope+1))[[4]]))   

adj.R2<-round(unlist(lapply(1:286, function(x) summary(lm(log(slope+1)~ log(temperature+1)  + species + log(dw), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_dw<-round(unlist(lapply(1:286, function(x) summary(lm(log(slope+1)~ log(dw), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_species<-round(unlist(lapply(1:286, function(x) summary(lm(log(slope+1)~ species, na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_temperature<-round(unlist(lapply(1:286, function(x) summary(lm(log(slope+1)~ log(temperature+1), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)

degrees_freedom<-unlist(lapply(1:286, function(x) cor.test(log(df_s[[x]]$dw),log(df_s[[x]]$slope+1))[[2]]))   

time<-unique(df$time)

plot(x=time,y=abs(correlations))

plot(x=time,y=degrees_freedom)

plot(x=time,y=adj.R2, ylim = c(0,0.4))
points(x=time, y= adj.R2_dw, col="red")
points(x=time, y= adj.R2_species, col="blue")
points(x=time, y= adj.R2_temperature, col="green")

######

library(ggplot2)
library(viridis)

df_ggplot <- data.frame(time = c(time, time, time, time),
           adj.R2 = c(adj.R2, adj.R2_dw, adj.R2_species, adj.R2_temperature),
           model_set = rep(c("all variables", "dry weight", " species", "temperature"), rep(length(time),4)))

df_ggplot$model_set <- factor(df_ggplot$model_set, levels = c("all variables", "dry weight", " species", "temperature"))

str(df_ggplot)

ggplot(df_ggplot, aes(x=time, y=adj.R2, color = model_set, group = model_set))+
  geom_line(size = 1)+
  scale_color_viridis_d() +
  labs(x = "Time (minutes)", y = "Adjusted R-square", color = "Model set:")+
  # guides(fill="none")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = 0.5),
        panel.grid.major = element_line(color = "gray", linewidth = 0.4),
        panel.grid.minor = element_line(color = "gray", size = 0.2),
        plot.tag.position = "topleft",
        panel.background = element_rect(fill = "white", colour = "black"),
        legend.position = "bottom",
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical",
        plot.margin = margin(0,2,0,0))  
  



corr_df<-data.frame(correlations=abs(correlations),time=time,adj_r2=adj.R2)

corr_df[corr_df$correlations==max(corr_df$correlations),] ## 18.75 minutes

corr_df[corr_df$adj_r2==max(corr_df$adj_r2),] ## 20 minutes


